@@ -5,7 +5,7 @@ ImageFile.LOAD_TRUNCATED_IMAGES=True  #If image is truncated(or corrupt) then al
 import torch
 
 class Cloader:
-    def __init__(self,image_path,targets,resize=False,transforms=False):
+    def __init__(self,image_path,targets,resize=None,transforms=None):
         self.image_path=image_path
         self.targets=targets
         self.resize=resize
