@@ -119,7 +119,7 @@ class Trainer:
                 targets.extend(data['targets'].cpu().numpy())
                 tk.set_description(f"current_loss: {loss.data.item():.4f} loss(avg): {val_loss:.4f}")
         if self.val_scheduler is not None:
-            if isinstance(self.val_scheduler, ReduceLROnPlateau):
+            if isinstance(self.val_scheduler, torch.optim.lr_scheduler.ReduceLROnPlateau):
                 self.val_scheduler.step(val_loss)
             else:
                 self.val_scheduler.step()
